# Superwise Python SDK

### A python SDK to integrate with Superwise

In order to use this library you need:

```
python > 3.0
```

### Install

Use pip to install the Superwise SDK

```
pip install superwise

```

## Versioning

We use [SemVer](http://semver.org/) for versioning. For all available versions, see the [tags in this repository](https://github.com/your/project/tags).


For getting started, HOWTOs, jupyter notebooks examples etc., head over to the Superwise documentation portal:  https://docs.superwise.ai/


## License
The Superwise SDK is released under the MIT licence (See LICENSE file)
